searchData={"content_type":"text/markdown","items":[{"doc":"Interface for making requests to an Onvif compatible device.\n\nCurrently supports WS Discovery probing, a subset of Device wsdl functions\nand a subset of Media wsdl functions.","ref":"ExOnvif.html","title":"ExOnvif","type":"module"},{"doc":"A Device is an abstraction of a physical piece of hardware.\n\nSetting up a device is done most easily by passing in the results\nof an ExOnvif.Discovery.Probe and credentials that can be used to\nperform ONVIF operations on the physical device.","ref":"ExOnvif.Device.html","title":"ExOnvif.Device","type":"module"},{"doc":"","ref":"ExOnvif.Device.html#changeset/2","title":"ExOnvif.Device.changeset/2","type":"function"},{"doc":"Returns a `{:ok, Device.t()}` tuple with device struct prepopulated with data required to make an Onvif API\nrequest.\n\n  `probe_match` is a valid `Probe.t()` struct for an Onvif compliant device.\n\n  `username` is an Onvif enabled username. Some manufacturers allow the admin credentials\n  to serve this purpose, but generally you need to enable Onvif for a user in the\n  device's web GUI or create dedicated credentials for ExOnvif.\n\n  `password` is the password for the username above.\n\n  `prefer_https?` will try requests via a probed https address if present. May run into SSL\n  errors so http is generally preferred.\n\n  `prefer_ipv6?` will try requests via a probed ipv6 address if present.\n\n`init` will attempt to make requests for the device's system datetime, an authenticated request\nfor device information, and an authenticated request for services to determine what the device's\nsystem can provide. As this makes several HTTP/HTTPS requests, there are several points of\nfailure which will return as `{:error, reason}`.\n\nIf `init` fails a device can be initialized with `new/3`, providing the address (in form `http://ip:port`),\nthe username and the password. Then override any other field with a struct update because the\ninit helpers haven't filled in any service paths, scopes, or an auth best guess.","ref":"ExOnvif.Device.html#init/5","title":"ExOnvif.Device.init/5","type":"function"},{"doc":"Returns a `Device.t()` struct populated with the bare requirements for making a request to an Onvif\nenabled device.\n\n  `address` is a http address with the form `http://ip:port`\n\n  `username` is the onvif enabled username\n\n  `password` is the password for the username\n\nAs this is an override for the init() function, your mileage may vary here, and some manual struct\nupdates may be required for the onvif requests to succeed. It is recommended to check calls on an\nauthentication required endpoint and swap out auth_type for the one that works.","ref":"ExOnvif.Device.html#new/3","title":"ExOnvif.Device.new/3","type":"function"},{"doc":"","ref":"ExOnvif.Device.html#t:t/0","title":"ExOnvif.Device.t/0","type":"type"},{"doc":"Utility function to encode a `Device.t()` struct into a json string.\n\nIt returns an `{:error, Ecto.Changeset.t()}` if the struct is not valid.","ref":"ExOnvif.Device.html#to_json/1","title":"ExOnvif.Device.to_json/1","type":"function"},{"doc":"Returns a `{:ok, Device.t()}` if the map can be properly parsed into a struct\nor `{:error, Ecto.Changeset.t()}` if not.","ref":"ExOnvif.Device.html#to_struct/1","title":"ExOnvif.Device.to_struct/1","type":"function"},{"doc":"Module for discovering devices on a local network via WS Discovery protocol","ref":"ExOnvif.Discovery.html","title":"ExOnvif.Discovery","type":"module"},{"doc":"Returns a list of `Probe.t()` that have responded via a UDP multicast call\non the local network. Devices on subnets / attached routers won't respond.\n\nDuplicate probes may be returned and it is up to the calling application to\nchoose how to filter out a duplicate.\n\n`opts` are a keyword list of options,\n- `:probe_timeout` denotes how long the probe will wait between new probe responses before closing out the\nlistener. There currently is no forced duration so if the network continuously\ngenerates probe messages this has the possibility to hang.\n- `:multicast_loop` defaults to false. Enabling it will allow host to echoing the multicast packets back to itself.\nThis is useful when this library runs in same device where you simulate a ONVIF device (https://www.happytimesoft.com/products/onvif-server/index.html)\n- `:ip_address` If the local host has many IP addresses, this option specifies which one to use.","ref":"ExOnvif.Discovery.html#probe/1","title":"ExOnvif.Discovery.probe/1","type":"function"},{"doc":"Returns a single `Probe.t()` or an error based on filter criteria provided.\n\nDuplicate matches to the criteria will only return the first probe that responded\nto the UDP multicast message. As this uses `probe/0` under the hood it is subject to\nthe same limitations and the default probe timeout.\n\n  `filter` can be a keyword list containing one of:\n\n  `serial` - device serial number, not guaranteed to be present\n\n  `ip_address` - device ip that responded to the onvif multicast\n\n  `mac_address` - device mac address, not guaranteed to be present. Accepts colon separated, dash separated, and only digits\n\n  `name` - device name, usually the model number or something manufacturer determined\n\n  `filter` can also be:\n\n  an onvif scope - `\"onvif://www.onvif.org/scope_name/scope_value\"`, not guaranteed to be present\n\n  a list of onvif scopes - matches the first one to succeed linking to a probe","ref":"ExOnvif.Discovery.html#probe_by/1","title":"ExOnvif.Discovery.probe_by/1","type":"function"},{"doc":"A struct representing a discovered device.","ref":"ExOnvif.Discovery.Probe.html","title":"ExOnvif.Discovery.Probe","type":"module"},{"doc":"","ref":"ExOnvif.Discovery.Probe.html#t:t/0","title":"ExOnvif.Discovery.Probe.t/0","type":"type"},{"doc":"","ref":"ExOnvif.MacAddress.html","title":"ExOnvif.MacAddress","type":"module"},{"doc":"","ref":"ExOnvif.MacAddress.html#mac_just_digits/1","title":"ExOnvif.MacAddress.mac_just_digits/1","type":"function"},{"doc":"","ref":"ExOnvif.MacAddress.html#mac_with_colons/1","title":"ExOnvif.MacAddress.mac_with_colons/1","type":"function"},{"doc":"Module describing an onvif request.","ref":"ExOnvif.Request.html","title":"ExOnvif.Request","type":"module"},{"doc":"Add namespaces to the request.\n\n  iex> request = %ExOnvif.Request{content: \"content\"}\n  iex> request = ExOnvif.Request.add_namespaces(request, [\"xmlns:wsse\": \"http://www.w3.org/2003/05/soap-envelope\"])\n  %ExOnvif.Request{content: \"content\", namespaces: [\"xmlns:wsse\": \"http://www.w3.org/2003/05/soap-envelope\"]}\n  iex> ExOnvif.Request.add_namespaces(request, [\"xmlns:wsa\": \"http://www.w3.org/2005/08/addressing\"])\n  %ExOnvif.Request{content: \"content\", namespaces: [\"xmlns:wsa\": \"http://www.w3.org/2005/08/addressing\", \"xmlns:wsse\": \"http://www.w3.org/2003/05/soap-envelope\"]}","ref":"ExOnvif.Request.html#add_namespaces/2","title":"ExOnvif.Request.add_namespaces/2","type":"function"},{"doc":"Serializes the request to a string.\n\n  iex> request = %ExOnvif.Request{content: \"content\", namespaces: [\"xmlns:s\": \"http://www.w3.org/2003/05/soap-envelope\"]}\n  iex> ExOnvif.Request.encode(request)\n  \" \\n  content\\n \"","ref":"ExOnvif.Request.html#encode/1","title":"ExOnvif.Request.encode/1","type":"function"},{"doc":"Puts a new header in the request.\n\n  iex> request = %ExOnvif.Request{content: \"content\"}\n  iex> ExOnvif.Request.put_header(request, :subscription_id, \"15\")\n  %ExOnvif.Request{content: \"content\", namespaces: [], header: %ExOnvif.Request.Header{subscription_id: \"15\"}}","ref":"ExOnvif.Request.html#put_header/3","title":"ExOnvif.Request.put_header/3","type":"function"},{"doc":"","ref":"ExOnvif.Request.html#t:t/0","title":"ExOnvif.Request.t/0","type":"type"},{"doc":"Struct describing onvif headers","ref":"ExOnvif.Request.Header.html","title":"ExOnvif.Request.Header","type":"module"},{"doc":"","ref":"ExOnvif.Request.Header.html#encode/1","title":"ExOnvif.Request.Header.encode/1","type":"function"},{"doc":"","ref":"ExOnvif.Request.Header.html#t:t/0","title":"ExOnvif.Request.Header.t/0","type":"type"},{"doc":"Interface for making requests to the Onvif analytics service\n\nhttps://www.onvif.org/ver20/analytics/wsdl/analytics.wsdl","ref":"ExOnvif.Analytics.html","title":"ExOnvif.Analytics","type":"module"},{"doc":"List the currently assigned set of analytics modules of a VideoAnalyticsConfiguration.","ref":"ExOnvif.Analytics.html#get_analytics_modules/2","title":"ExOnvif.Analytics.get_analytics_modules/2","type":"function"},{"doc":"Returns the capabilities of the analytics service.","ref":"ExOnvif.Analytics.html#get_service_capabilities/1","title":"ExOnvif.Analytics.get_service_capabilities/1","type":"function"},{"doc":"Interface for making requests to the Onvif devices service\n\nhttps://www.onvif.org/ver10/device/wsdl/devicemgmt.wsdl","ref":"ExOnvif.Devices.html","title":"ExOnvif.Devices","type":"module"},{"doc":"This operation gets basic device information from the device.","ref":"ExOnvif.Devices.html#get_device_information/1","title":"ExOnvif.Devices.get_device_information/1","type":"function"},{"doc":"This operation is used by an endpoint to get the hostname from a device.","ref":"ExOnvif.Devices.html#get_hostname/1","title":"ExOnvif.Devices.get_hostname/1","type":"function"},{"doc":"This operation gets the network interface configuration from a device.","ref":"ExOnvif.Devices.html#get_network_interfaces/1","title":"ExOnvif.Devices.get_network_interfaces/1","type":"function"},{"doc":"This operation gets defined network protocols from a device.","ref":"ExOnvif.Devices.html#get_network_protocols/1","title":"ExOnvif.Devices.get_network_protocols/1","type":"function"},{"doc":"This operation gets the NTP settings from a device.","ref":"ExOnvif.Devices.html#get_ntp/1","title":"ExOnvif.Devices.get_ntp/1","type":"function"},{"doc":"This operation requests the scope parameters of a device.\n\nThe scope parameters are used in the device discovery to match a probe message. The Scope parameters are of two different types:\n  * Fixed\n  * Configurable\n\nFixed scope parameters are permanent device characteristics and cannot be removed through the device management interface.\nThe scope type is indicated in the scope list returned in the get scope parameters response. A device shall support retrieval\nof discovery scope parameters through the GetScopes command.\n\nAs some scope parameters are mandatory, the device shall return a non-empty scope list in the response.","ref":"ExOnvif.Devices.html#get_scopes/1","title":"ExOnvif.Devices.get_scopes/1","type":"function"},{"doc":"Returns the capabilities of the device service.","ref":"ExOnvif.Devices.html#get_service_capabilities/1","title":"ExOnvif.Devices.get_service_capabilities/1","type":"function"},{"doc":"Returns information about services on the device.","ref":"ExOnvif.Devices.html#get_services/1","title":"ExOnvif.Devices.get_services/1","type":"function"},{"doc":"This operation gets the device system date and time. The device shall support the return of the daylight saving setting and of the manual\nsystem date and time (if applicable) or indication of NTP time (if applicable) through the GetSystemDateAndTime command.","ref":"ExOnvif.Devices.html#get_system_date_and_time/1","title":"ExOnvif.Devices.get_system_date_and_time/1","type":"function"},{"doc":"This operation configures defined network protocols on a device.","ref":"ExOnvif.Devices.html#set_network_protocols/2","title":"ExOnvif.Devices.set_network_protocols/2","type":"function"},{"doc":"This operation sets the NTP settings on a device. If the device supports NTP, it shall be possible to set the NTP server settings through\nthe SetNTP command.\n\nA device shall accept string formated according to RFC 1123 section 2.1 or alternatively to RFC 952, other string shall be considered\nas invalid strings.\n\nChanges to the NTP server list will not affect the clock mode DateTimeType. Use SetSystemDateAndTime to activate NTP operation.","ref":"ExOnvif.Devices.html#set_ntp/2","title":"ExOnvif.Devices.set_ntp/2","type":"function"},{"doc":"This operation sets the device system date and time. The device shall support the configuration of the daylight saving setting and of the manual\nsystem date and time (if applicable) or indication of NTP time (if applicable) through the SetSystemDateAndTime command.\n\nIf system time and date are set manually, the client shall include UTCDateTime in the request.\n\nA TimeZone token which is not formed according to the rules of IEEE 1003.1 section 8.3 is considered as invalid timezone.\n\nThe DayLightSavings flag should be set to true to activate any DST settings of the TimeZone string.\nClear the DayLightSavings flag if the DST portion of the TimeZone settings should be ignored.","ref":"ExOnvif.Devices.html#set_system_date_and_time/2","title":"ExOnvif.Devices.set_system_date_and_time/2","type":"function"},{"doc":"This operation reboots the device.","ref":"ExOnvif.Devices.html#system_reboot/1","title":"ExOnvif.Devices.system_reboot/1","type":"function"},{"doc":"Interface for making requests to the Onvif event service\n\nhttps://www.onvif.org/ver10/events/wsdl/event.wsdl","ref":"ExOnvif.Event.html","title":"ExOnvif.Event","type":"module"},{"doc":"This method returns a PullPointSubscription that can be polled using PullMessages.\n\nThis message contains the same elements as the SubscriptionRequest of the WS-BaseNotification without the ConsumerReference.\n\nIf no Filter is specified the pullpoint notifies all occurring events to the client.","ref":"ExOnvif.Event.html#create_pull_point_subscription/2","title":"ExOnvif.Event.create_pull_point_subscription/2","type":"function"},{"doc":"Returns the capabilities of the event service.","ref":"ExOnvif.Event.html#get_service_capabilities/1","title":"ExOnvif.Event.get_service_capabilities/1","type":"function"},{"doc":"Interface for making requests to the 1.0 version of Onvif Media Service\n\nhttps://www.onvif.org/ver10/media/wsdl/media.wsdl","ref":"ExOnvif.Media.html","title":"ExOnvif.Media","type":"module"},{"doc":"Create the OSD.","ref":"ExOnvif.Media.html#create_osd/2","title":"ExOnvif.Media.create_osd/2","type":"function"},{"doc":"Delete the OSD with the provided token.","ref":"ExOnvif.Media.html#delete_osd/2","title":"ExOnvif.Media.delete_osd/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.html#t:encoder_options_opts/0","title":"ExOnvif.Media.encoder_options_opts/0","type":"type"},{"doc":"This operation returns the available options (supported values and ranges for audio encoder configuration parameters) when the audio encoder\nparameters are reconfigured.","ref":"ExOnvif.Media.html#get_audio_configuration_options/2","title":"ExOnvif.Media.get_audio_configuration_options/2","type":"function"},{"doc":"The GetAudioEncoderConfiguration command fetches the encoder configuration if the audio encoder configuration token is known.","ref":"ExOnvif.Media.html#get_audio_encoder_configuration/2","title":"ExOnvif.Media.get_audio_encoder_configuration/2","type":"function"},{"doc":"Get OSD by token.","ref":"ExOnvif.Media.html#get_osd/2","title":"ExOnvif.Media.get_osd/2","type":"function"},{"doc":"Get the OSD Options.","ref":"ExOnvif.Media.html#get_osd_options/2","title":"ExOnvif.Media.get_osd_options/2","type":"function"},{"doc":"Get the OSDs.","ref":"ExOnvif.Media.html#get_osds/2","title":"ExOnvif.Media.get_osds/2","type":"function"},{"doc":"Get profile by token.","ref":"ExOnvif.Media.html#get_profile/2","title":"ExOnvif.Media.get_profile/2","type":"function"},{"doc":"Get existing media profiles of a device.\n\nPre-configured or dynamically configured profiles can be retrieved using this command. This command lists all configured\nprofiles in a device. The client does not need to know the media profile in order to use the command.","ref":"ExOnvif.Media.html#get_profiles/1","title":"ExOnvif.Media.get_profiles/1","type":"function"},{"doc":"Returns the capabilities of the media service.","ref":"ExOnvif.Media.html#get_service_capabilities/1","title":"ExOnvif.Media.get_service_capabilities/1","type":"function"},{"doc":"A client uses the GetSnapshotUri command to obtain a JPEG snapshot from the device.\n\nThe URI can be used for acquiring a JPEG image through a HTTP GET operation. The image encoding will always be JPEG regardless\nof the encoding setting in the media profile. The Jpeg settings (like resolution or quality) may be taken from the profile if suitable.","ref":"ExOnvif.Media.html#get_snapshot_uri/2","title":"ExOnvif.Media.get_snapshot_uri/2","type":"function"},{"doc":"This operation requests a URI that can be used to initiate a live media stream using RTSP as the control protocol.\n\nThe correct syntax for the StreamSetup element for these media stream setups defined in 5.1.1 of the streaming specification are as follows:\n  * RTP unicast over UDP: StreamType = \"RTP_unicast\", TransportProtocol = \"UDP\"\n  * RTP over RTSP over HTTP over TCP: StreamType = \"RTP_unicast\", TransportProtocol = \"HTTP\"\n  * RTP over RTSP over TCP: StreamType = \"RTP_unicast\", TransportProtocol = \"RTSP\"\n\nIf a multicast stream is requested at least one of VideoEncoderConfiguration, AudioEncoderConfiguration and MetadataConfiguration shall have a valid\nmulticast setting.","ref":"ExOnvif.Media.html#get_stream_uri/4","title":"ExOnvif.Media.get_stream_uri/4","type":"function"},{"doc":"If the video encoder configuration token is already known, the encoder configuration can be fetched through the GetVideoEncoderConfiguration command.","ref":"ExOnvif.Media.html#get_video_encoder_configuration/2","title":"ExOnvif.Media.get_video_encoder_configuration/2","type":"function"},{"doc":"This operation returns the available options (supported values and ranges for video encoder configuration parameters) when the video encoder parameters\nare reconfigured.\n\nFor JPEG, MPEG4 and H264 extension elements have been defined that provide additional information. A device must provide the XxxOption information\nfor all encodings supported and should additionally provide the corresponding XxxOption2 information.\n\nThis response contains the available video encoder configuration options. If a video encoder configuration is specified,\nthe options shall concern that particular configuration. If a media profile is specified, the options shall be compatible\nwith that media profile. If no tokens are specified, the options shall be considered generic for the device.","ref":"ExOnvif.Media.html#get_video_encoder_configuration_options/2","title":"ExOnvif.Media.get_video_encoder_configuration_options/2","type":"function"},{"doc":"This operation modifies an audio encoder configuration.\n\nThe ForcePersistence flag indicates if the changes shall remain after reboot of the device. Running streams using this configuration may be immediately updated according to the new settings. The changes are not guaranteed to take effect unless the client requests a new stream URI and restarts any affected streams. NVC methods for changing a running stream are out of scope for this specification.","ref":"ExOnvif.Media.html#set_audio_encoder_configuration/2","title":"ExOnvif.Media.set_audio_encoder_configuration/2","type":"function"},{"doc":"Set the OSD","ref":"ExOnvif.Media.html#set_osd/2","title":"ExOnvif.Media.set_osd/2","type":"function"},{"doc":"This operation modifies a video encoder configuration.\n\nThe ForcePersistence flag indicates if the changes shall remain after reboot of the device. Changes in the Multicast settings\nshall always be persistent. Running streams using this configuration may be immediately updated according to the new settings.\nThe changes are not guaranteed to take effect unless the client requests a new stream URI and restarts any affected stream.\nNVC methods for changing a running stream are out of scope for this specification.\n\nSessionTimeout is provided as a hint for keeping rtsp session by a device. If necessary the device may adapt parameter\nvalues for SessionTimeout elements without returning an error. For the time between keep alive calls the client shall adhere\nto the timeout value signaled via RTSP.","ref":"ExOnvif.Media.html#set_video_encoder_configuration/2","title":"ExOnvif.Media.set_video_encoder_configuration/2","type":"function"},{"doc":"Interface for making requests to the version 2.0 of Onvif Media Service\n\nhttps://www.onvif.org/ver20/media/wsdl/media.wsdl","ref":"ExOnvif.Media2.html","title":"ExOnvif.Media2","type":"module"},{"doc":"This operation adds one or more Configurations to an existing media profile.\n\nIf a configuration exists in the media profile, it will be replaced. A device shall support adding a compatible Configuration to a Profile\ncontaining a VideoSourceConfiguration and shall support streaming video data of such a profile.","ref":"ExOnvif.Media2.html#add_configuration/2","title":"ExOnvif.Media2.add_configuration/2","type":"function"},{"doc":"This operation creates a new media profile.\n\nA created profile created via this method may be deleted via the DeleteProfile method. Optionally Configurations\ncan be assinged to the profile on creation. For details regarding profile assignement check also the method `add_configuration/2`.","ref":"ExOnvif.Media2.html#create_profile/3","title":"ExOnvif.Media2.create_profile/3","type":"function"},{"doc":"","ref":"ExOnvif.Media2.html#t:encoder_options_opts/0","title":"ExOnvif.Media2.encoder_options_opts/0","type":"type"},{"doc":"By default this operation lists all existing audio encoder configurations for a device.\n\nProvide a profile token to list only configurations that are compatible with the profile. If a configuration\ntoken is provided only a single configuration will be returned.","ref":"ExOnvif.Media2.html#get_audio_encoder_configurations/2","title":"ExOnvif.Media2.get_audio_encoder_configurations/2","type":"function"},{"doc":"By default this operation lists all existing metadata configurations for a device.\n\nProvide a profile token to list only configurations that are compatible with the profile. If a configuration token is provided only a single\nconfiguration will be returned.","ref":"ExOnvif.Media2.html#get_metadata_configurations/2","title":"ExOnvif.Media2.get_metadata_configurations/2","type":"function"},{"doc":"Retrieve the profile with the specified token or all defined media profiles.\n\n  * If no Type is provided the returned profiles shall contain no configuration information.\n  * If a single Type with value 'All' is provided the returned profiles shall include all associated configurations.\n  * Otherwise the requested list of configurations shall for each profile include the configurations present as Type.","ref":"ExOnvif.Media2.html#get_profiles/2","title":"ExOnvif.Media2.get_profiles/2","type":"function"},{"doc":"Returns the capabilities of the media service.","ref":"ExOnvif.Media2.html#get_service_capabilities/1","title":"ExOnvif.Media2.get_service_capabilities/1","type":"function"},{"doc":"A client uses the GetSnapshotUri command to obtain a JPEG snapshot from the device.\n\nThe returned URI shall remain valid indefinitely even if the profile is changed. The URI can be used for acquiring a JPEG image\nthrough an HTTP GET operation. The image encoding will always be JPEG regardless of the encoding setting in the media profile.\nThe Jpeg settings (like resolution or quality) may be taken from the profile if suitable. The provided image will be updated automatically\nand independent from calls to GetSnapshotUri.","ref":"ExOnvif.Media2.html#get_snapshot_uri/2","title":"ExOnvif.Media2.get_snapshot_uri/2","type":"function"},{"doc":"This operation requests a URI that can be used to initiate a live media stream using RTSP as the control protocol.\n\nThe returned URI shall remain valid indefinitely even if the profile is changed.\n\nDefined stream types are\n  * RtspUnicast RTSP streaming RTP as UDP Unicast.\n  * RtspMulticast RTSP streaming RTP as UDP Multicast.\n  * RTSP RTSP streaming RTP over TCP.\n  * RtspOverHttp Tunneling both the RTSP control channel and the RTP stream over HTTP or HTTPS.\n\nIf a multicast stream is requested at least one of VideoEncoder2Configuration, AudioEncoder2Configuration and MetadataConfiguration\nshall have a valid multicast setting.","ref":"ExOnvif.Media2.html#get_stream_uri/2","title":"ExOnvif.Media2.get_stream_uri/2","type":"function"},{"doc":"This operation returns the available options (supported values and ranges for video encoder configuration parameters) when the video encoder\nparameters are reconfigured.\n\nThis response contains the available video encoder configuration options. If a video encoder configuration is specified,\nthe options shall concern that particular configuration. If a media profile is specified, the options shall be compatible with that media profile.\nIf no tokens are specified, the options shall be considered generic for the device.","ref":"ExOnvif.Media2.html#get_video_encoder_configuration_options/2","title":"ExOnvif.Media2.get_video_encoder_configuration_options/2","type":"function"},{"doc":"By default this operation lists all existing video encoder configurations for a device.\n\nProvide a profile token to list only configurations that are compatible with the profile. If a configuration token\nis provided only a single configuration will be returned.","ref":"ExOnvif.Media2.html#get_video_encoder_configurations/2","title":"ExOnvif.Media2.get_video_encoder_configurations/2","type":"function"},{"doc":"By default this operation lists all existing video source configurations for a device.\n\nProvide a profile token to list only configurations that are compatible with the profile. If a configuration token\nis provided only a single configuration will be returned.","ref":"ExOnvif.Media2.html#get_video_source_configurations/2","title":"ExOnvif.Media2.get_video_source_configurations/2","type":"function"},{"doc":"This operation modifies an audio encoder configuration.\n\nRunning streams using this configuration may be immediately updated according to the new settings. The changes are not guaranteed\nto take effect unless the client requests a new stream URI and restarts any affected streams.","ref":"ExOnvif.Media2.html#set_audio_encoder_configuration/2","title":"ExOnvif.Media2.set_audio_encoder_configuration/2","type":"function"},{"doc":"This operation modifies a video encoder configuration.\n\nRunning streams using this configuration may be immediately updated according to the new settings. The changes are not guaranteed to take\neffect unless the client requests a new stream URI and restarts any affected stream.\n\nSessionTimeout is provided as a hint for keeping rtsp session by a device. If necessary the device may adapt\nparameter values for SessionTimeout elements without returning an error. For the time between keep alive calls the client\nshall adhere to the timeout value signaled via RTSP.","ref":"ExOnvif.Media2.html#set_video_encoder_configuration/2","title":"ExOnvif.Media2.set_video_encoder_configuration/2","type":"function"},{"doc":"Interface for making requests to the Onvif PTZ(Pan/Tilt/Zoom) service\n\nhttps://www.onvif.org/onvif/ver20/ptz/wsdl/ptz.wsdl","ref":"ExOnvif.PTZ.html","title":"ExOnvif.PTZ","type":"module"},{"doc":"Operation to move pan,tilt or zoom to a absolute destination.\n\nThe speed argument is optional. If an x/y speed value is given it is up to the device to either use the x value as absolute resoluting\nspeed vector or to map x and y to the component speed. If the speed argument is omitted, the default speed set by the\nPTZConfiguration will be used.","ref":"ExOnvif.PTZ.html#absolute_move/2","title":"ExOnvif.PTZ.absolute_move/2","type":"function"},{"doc":"Get a specific PTZ Node identified by a reference token or a name.","ref":"ExOnvif.PTZ.html#get_node/2","title":"ExOnvif.PTZ.get_node/2","type":"function"},{"doc":"Get the descriptions of the available PTZ Nodes.\n\nA PTZ-capable device may have multiple PTZ Nodes. The PTZ Nodes may represent mechanical PTZ drivers, uploaded PTZ drivers or digital PTZ drivers.\nPTZ Nodes are the lowest level entities in the PTZ control API and reflect the supported PTZ capabilities. The PTZ Node is referenced\neither by its name or by its reference token.","ref":"ExOnvif.PTZ.html#get_nodes/1","title":"ExOnvif.PTZ.get_nodes/1","type":"function"},{"doc":"Returns the capabilities of the PTZ service.","ref":"ExOnvif.PTZ.html#get_service_capabilities/1","title":"ExOnvif.PTZ.get_service_capabilities/1","type":"function"},{"doc":"Operation to request PTZ status for the Node in the selected profile.","ref":"ExOnvif.PTZ.html#get_status/2","title":"ExOnvif.PTZ.get_status/2","type":"function"},{"doc":"Interface for making requests to the PullPoint service.","ref":"ExOnvif.PullPoint.html","title":"ExOnvif.PullPoint","type":"module"},{"doc":"This method pulls one or more messages from a PullPoint.\n\nThe device shall provide the following PullMessages command for all SubscriptionManager endpoints returned by the CreatePullPointSubscription command.\nThis method shall not wait until the requested number of messages is available but return as soon as at least one message is available.\n\nThe following options may be provided:\n  * `timeout` - Timeout in seconds. Defaults to: 2\n  * `message_limit` - The max number messages to retrieve from the pull point. Defaults to: 10\n  * `subscription_id` - Subscription id to include as header in the soap request.","ref":"ExOnvif.PullPoint.html#pull_messages/3","title":"ExOnvif.PullPoint.pull_messages/3","type":"function"},{"doc":"Interface for making requests to the Onvif recording service\n\nhttp://www.onvif.org/onvif/ver10/recording.wsdl","ref":"ExOnvif.Recording.html","title":"ExOnvif.Recording","type":"module"},{"doc":"CreateRecording shall create a new recording.\n\nThe new recording shall be created with a track for each supported\nTrackType see Recording Control Spec.\n\nThis method is optional. It shall be available if the Recording/DynamicRecordings capability is TRUE.\n\nWhen successfully completed, CreateRecording shall have created three tracks with the following configurations:\n  * TrackToken TrackType\n  * VIDEO001 Video\n  * AUDIO001 Audio\n  * META001 Metadata\n\nAll TrackConfigurations shall have the MaximumRetentionTime set to 0 (unlimited), and the Description set to the empty string.","ref":"ExOnvif.Recording.html#create_recording/2","title":"ExOnvif.Recording.create_recording/2","type":"function"},{"doc":"CreateRecordingJob shall create a new recording job.\n\nThe JobConfiguration returned from CreateRecordingJob shall be identical to the JobConfiguration passed into CreateRecordingJob,\nexcept for the ReceiverToken and the AutoCreateReceiver. In the returned structure, the ReceiverToken shall be present and valid\nand the AutoCreateReceiver field shall be omitted.","ref":"ExOnvif.Recording.html#create_recording_job/2","title":"ExOnvif.Recording.create_recording_job/2","type":"function"},{"doc":"GetRecordingJobs shall return a list of all the recording jobs in the device.","ref":"ExOnvif.Recording.html#get_recording_jobs/1","title":"ExOnvif.Recording.get_recording_jobs/1","type":"function"},{"doc":"GetRecordings shall return a description of all the recordings in the device.\n\nThis description shall include a list of all the tracks for each recording.","ref":"ExOnvif.Recording.html#get_recordings/1","title":"ExOnvif.Recording.get_recordings/1","type":"function"},{"doc":"Returns the capabilities of the recording service.","ref":"ExOnvif.Recording.html#get_service_capabilities/1","title":"ExOnvif.Recording.get_service_capabilities/1","type":"function"},{"doc":"Interface for making requests to the Onvif replay service\n\nhttps://www.onvif.org/ver10/replay.wsdl","ref":"ExOnvif.Replay.html","title":"ExOnvif.Replay","type":"module"},{"doc":"Requests a URI that can be used to initiate playback of a recorded stream using RTSP as the control protocol.\n\nThe URI is valid only as it is specified in the response.","ref":"ExOnvif.Replay.html#get_replay_uri/3","title":"ExOnvif.Replay.get_replay_uri/3","type":"function"},{"doc":"Returns the capabilities of the replay service.","ref":"ExOnvif.Replay.html#get_service_capabilities/1","title":"ExOnvif.Replay.get_service_capabilities/1","type":"function"},{"doc":"Interface for making requests to the Onvif search service\n\nhttps://www.onvif.org/ver10/search.wsdl","ref":"ExOnvif.Search.html","title":"ExOnvif.Search","type":"module"},{"doc":"FindEvents starts a search session, looking for recording events (in the scope that matches the search filter defined in the request).\n\nResults from the search are acquired using the `get_event_search_results/2` request, specifying the search token returned from this request.\n\nThe device shall continue searching until one of the following occurs:\n  * The entire time range from StartPoint to EndPoint has been searched through.\n  * The total number of matches has been found, defined by the MaxMatches parameter.\n  * The session has been ended by a client EndSession request.\n  * The session has been ended because KeepAliveTime since the last request related to this session has expired.\n\nResults shall be ordered by time, ascending in case of forward search, or descending in case of backward search.\nThis operation is mandatory to support for a device implementing the recording search service.","ref":"ExOnvif.Search.html#find_events/2","title":"ExOnvif.Search.find_events/2","type":"function"},{"doc":"FindRecordings starts a search session, looking for recordings that matches the scope (See 20.2.4) defined in the request.\n\nResults from the search are acquired using the GetRecordingSearchResults request, specifying the search token returned from this request.\nThe device shall continue searching until one of the following occurs:\n  * The entire time range from StartPoint to EndPoint has been searched through.\n  * The total number of matches has been found, defined by the MaxMatches parameter.\n  * The session has been ended by a client EndSession request.\n  * The session has been ended because KeepAliveTime since the last request related to this session has expired.\n\nThe order of the results is undefined, to allow the device to return results in any order they are found.\nThis operation is mandatory to support for a device implementing the recording search service.","ref":"ExOnvif.Search.html#find_recordings/2","title":"ExOnvif.Search.find_recordings/2","type":"function"},{"doc":"GetRecordingSearchResults acquires the results from a recording search session previously initiated\nby a `ExOnvif.Search.find_recordings/2` operation. The response shall not include results already\nreturned in previous requests for the same session.\n\nIf MaxResults is specified, the response shall not contain more than MaxResults results.\nThe number of results relates to the number of recordings. For viewing individual recorded data\nfor a signal track use the FindEvents method.\n\nGetRecordingSearchResults shall block until:\n  * MaxResults results are available for the response if MaxResults is specified.\n  * MinResults results are available for the response if MinResults is specified.\n  * WaitTime has expired.\n  * Search is completed or stopped.","ref":"ExOnvif.Search.html#get_recording_search_results/2","title":"ExOnvif.Search.get_recording_search_results/2","type":"function"},{"doc":"GetRecordingSummary is used to get a summary description of all recorded data.","ref":"ExOnvif.Search.html#get_recording_summary/1","title":"ExOnvif.Search.get_recording_summary/1","type":"function"},{"doc":"Schema describing an analytics module.","ref":"ExOnvif.Analytics.Module.html","title":"ExOnvif.Analytics.Module","type":"module"},{"doc":"","ref":"ExOnvif.Analytics.Module.html#changeset/2","title":"ExOnvif.Analytics.Module.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Analytics.Module.html#parse/1","title":"ExOnvif.Analytics.Module.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Analytics.Module.html#t:t/0","title":"ExOnvif.Analytics.Module.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Analytics.Module.html#to_struct/1","title":"ExOnvif.Analytics.Module.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Analytics.Module.Parameters.html","title":"ExOnvif.Analytics.Module.Parameters","type":"module"},{"doc":"","ref":"ExOnvif.Analytics.Module.Parameters.html#t:t/0","title":"ExOnvif.Analytics.Module.Parameters.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Analytics.Module.Parameters.ElementItem.html","title":"ExOnvif.Analytics.Module.Parameters.ElementItem","type":"module"},{"doc":"","ref":"ExOnvif.Analytics.Module.Parameters.ElementItem.html#t:t/0","title":"ExOnvif.Analytics.Module.Parameters.ElementItem.t/0","type":"type"},{"doc":"Schema describing the capabilities of the analytics service.","ref":"ExOnvif.Analytics.ServiceCapabilities.html","title":"ExOnvif.Analytics.ServiceCapabilities","type":"module"},{"doc":"","ref":"ExOnvif.Analytics.ServiceCapabilities.html#changeset/2","title":"ExOnvif.Analytics.ServiceCapabilities.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Analytics.ServiceCapabilities.html#parse/1","title":"ExOnvif.Analytics.ServiceCapabilities.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Analytics.ServiceCapabilities.html#t:t/0","title":"ExOnvif.Analytics.ServiceCapabilities.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Analytics.ServiceCapabilities.html#to_struct/1","title":"ExOnvif.Analytics.ServiceCapabilities.to_struct/1","type":"function"},{"doc":"Schema describing a transformation.","ref":"ExOnvif.Analytics.Transformation.html","title":"ExOnvif.Analytics.Transformation","type":"module"},{"doc":"","ref":"ExOnvif.Analytics.Transformation.html#changeset/2","title":"ExOnvif.Analytics.Transformation.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Analytics.Transformation.html#parse/1","title":"ExOnvif.Analytics.Transformation.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Analytics.Transformation.html#scale_changeset/2","title":"ExOnvif.Analytics.Transformation.scale_changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Analytics.Transformation.html#t:t/0","title":"ExOnvif.Analytics.Transformation.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Analytics.Transformation.html#to_struct/1","title":"ExOnvif.Analytics.Transformation.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Analytics.Transformation.Scale.html","title":"ExOnvif.Analytics.Transformation.Scale","type":"module"},{"doc":"","ref":"ExOnvif.Analytics.Transformation.Scale.html#t:t/0","title":"ExOnvif.Analytics.Transformation.Scale.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Analytics.Transformation.Translate.html","title":"ExOnvif.Analytics.Transformation.Translate","type":"module"},{"doc":"","ref":"ExOnvif.Analytics.Transformation.Translate.html#t:t/0","title":"ExOnvif.Analytics.Transformation.Translate.t/0","type":"type"},{"doc":"DeviceInformation schema","ref":"ExOnvif.Devices.DeviceInformation.html","title":"ExOnvif.Devices.DeviceInformation","type":"module"},{"doc":"","ref":"ExOnvif.Devices.DeviceInformation.html#changeset/2","title":"ExOnvif.Devices.DeviceInformation.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Devices.DeviceInformation.html#parse/1","title":"ExOnvif.Devices.DeviceInformation.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.DeviceInformation.html#t:t/0","title":"ExOnvif.Devices.DeviceInformation.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Devices.DeviceInformation.html#to_json/1","title":"ExOnvif.Devices.DeviceInformation.to_json/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.DeviceInformation.html#to_struct/1","title":"ExOnvif.Devices.DeviceInformation.to_struct/1","type":"function"},{"doc":"Scheme describing the hostname information of a device.","ref":"ExOnvif.Devices.HostnameInformation.html","title":"ExOnvif.Devices.HostnameInformation","type":"module"},{"doc":"","ref":"ExOnvif.Devices.HostnameInformation.html#changeset/2","title":"ExOnvif.Devices.HostnameInformation.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Devices.HostnameInformation.html#parse/1","title":"ExOnvif.Devices.HostnameInformation.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.HostnameInformation.html#t:t/0","title":"ExOnvif.Devices.HostnameInformation.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Devices.HostnameInformation.html#to_struct/1","title":"ExOnvif.Devices.HostnameInformation.to_struct/1","type":"function"},{"doc":"Schema for the NTP configuration to be used with SetNTP and GetNTP operations.","ref":"ExOnvif.Devices.NTP.html","title":"ExOnvif.Devices.NTP","type":"module"},{"doc":"","ref":"ExOnvif.Devices.NTP.html#changeset/2","title":"ExOnvif.Devices.NTP.changeset/2","type":"function"},{"doc":"Encode to XML.","ref":"ExOnvif.Devices.NTP.html#encode/1","title":"ExOnvif.Devices.NTP.encode/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.NTP.html#parse/1","title":"ExOnvif.Devices.NTP.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.NTP.html#t:t/0","title":"ExOnvif.Devices.NTP.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Devices.NTP.html#to_struct/1","title":"ExOnvif.Devices.NTP.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.NTP.NTPFromDHCP.html","title":"ExOnvif.Devices.NTP.NTPFromDHCP","type":"module"},{"doc":"","ref":"ExOnvif.Devices.NTP.NTPManual.html","title":"ExOnvif.Devices.NTP.NTPManual","type":"module"},{"doc":"Device's network interface","ref":"ExOnvif.Devices.NetworkInterface.html","title":"ExOnvif.Devices.NetworkInterface","type":"module"},{"doc":"","ref":"ExOnvif.Devices.NetworkInterface.html#changeset/2","title":"ExOnvif.Devices.NetworkInterface.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Devices.NetworkInterface.html#parse/1","title":"ExOnvif.Devices.NetworkInterface.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.NetworkInterface.html#t:t/0","title":"ExOnvif.Devices.NetworkInterface.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Devices.NetworkInterface.html#to_struct/1","title":"ExOnvif.Devices.NetworkInterface.to_struct/1","type":"function"},{"doc":"Schema describing a connection setting.","ref":"ExOnvif.Devices.NetworkInterface.ConnectionSetting.html","title":"ExOnvif.Devices.NetworkInterface.ConnectionSetting","type":"module"},{"doc":"","ref":"ExOnvif.Devices.NetworkInterface.ConnectionSetting.html#changeset/2","title":"ExOnvif.Devices.NetworkInterface.ConnectionSetting.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Devices.NetworkInterface.ConnectionSetting.html#parse/1","title":"ExOnvif.Devices.NetworkInterface.ConnectionSetting.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.NetworkInterface.ConnectionSetting.html#t:t/0","title":"ExOnvif.Devices.NetworkInterface.ConnectionSetting.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Devices.NetworkInterface.IPv4.html","title":"ExOnvif.Devices.NetworkInterface.IPv4","type":"module"},{"doc":"","ref":"ExOnvif.Devices.NetworkInterface.IPv4.Config.html","title":"ExOnvif.Devices.NetworkInterface.IPv4.Config","type":"module"},{"doc":"","ref":"ExOnvif.Devices.NetworkInterface.IPv6.html","title":"ExOnvif.Devices.NetworkInterface.IPv6","type":"module"},{"doc":"","ref":"ExOnvif.Devices.NetworkInterface.IPv6.Config.html","title":"ExOnvif.Devices.NetworkInterface.IPv6.Config","type":"module"},{"doc":"","ref":"ExOnvif.Devices.NetworkInterface.Info.html","title":"ExOnvif.Devices.NetworkInterface.Info","type":"module"},{"doc":"","ref":"ExOnvif.Devices.NetworkInterface.Link.html","title":"ExOnvif.Devices.NetworkInterface.Link","type":"module"},{"doc":"Schema describing a prefixed IPv4/IPv6 address.","ref":"ExOnvif.Devices.NetworkInterface.PrefixedIPAddress.html","title":"ExOnvif.Devices.NetworkInterface.PrefixedIPAddress","type":"module"},{"doc":"","ref":"ExOnvif.Devices.NetworkInterface.PrefixedIPAddress.html#changeset/2","title":"ExOnvif.Devices.NetworkInterface.PrefixedIPAddress.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Devices.NetworkInterface.PrefixedIPAddress.html#parse/1","title":"ExOnvif.Devices.NetworkInterface.PrefixedIPAddress.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.NetworkInterface.PrefixedIPAddress.html#t:t/0","title":"ExOnvif.Devices.NetworkInterface.PrefixedIPAddress.t/0","type":"type"},{"doc":"A module describing a network protocol.","ref":"ExOnvif.Devices.NetworkProtocol.html","title":"ExOnvif.Devices.NetworkProtocol","type":"module"},{"doc":"","ref":"ExOnvif.Devices.NetworkProtocol.html#changeset/2","title":"ExOnvif.Devices.NetworkProtocol.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Devices.NetworkProtocol.html#encode/1","title":"ExOnvif.Devices.NetworkProtocol.encode/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.NetworkProtocol.html#parse/1","title":"ExOnvif.Devices.NetworkProtocol.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.NetworkProtocol.html#t:t/0","title":"ExOnvif.Devices.NetworkProtocol.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Devices.NetworkProtocol.html#to_struct/1","title":"ExOnvif.Devices.NetworkProtocol.to_struct/1","type":"function"},{"doc":"Scheme describing device scope.","ref":"ExOnvif.Devices.Scope.html","title":"ExOnvif.Devices.Scope","type":"module"},{"doc":"","ref":"ExOnvif.Devices.Scope.html#changeset/2","title":"ExOnvif.Devices.Scope.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Devices.Scope.html#parse/1","title":"ExOnvif.Devices.Scope.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.Scope.html#t:t/0","title":"ExOnvif.Devices.Scope.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Devices.Scope.html#to_struct/1","title":"ExOnvif.Devices.Scope.to_struct/1","type":"function"},{"doc":"Service schema that outlines namespaces and versions","ref":"ExOnvif.Devices.Service.html","title":"ExOnvif.Devices.Service","type":"module"},{"doc":"","ref":"ExOnvif.Devices.Service.html#changeset/2","title":"ExOnvif.Devices.Service.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Devices.Service.html#parse/1","title":"ExOnvif.Devices.Service.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.Service.html#t:t/0","title":"ExOnvif.Devices.Service.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Devices.Service.html#to_json/1","title":"ExOnvif.Devices.Service.to_json/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.Service.html#to_struct/1","title":"ExOnvif.Devices.Service.to_struct/1","type":"function"},{"doc":"Schema describing device service capabilities.","ref":"ExOnvif.Devices.ServiceCapabilities.html","title":"ExOnvif.Devices.ServiceCapabilities","type":"module"},{"doc":"","ref":"ExOnvif.Devices.ServiceCapabilities.html#changeset/2","title":"ExOnvif.Devices.ServiceCapabilities.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Devices.ServiceCapabilities.html#parse/1","title":"ExOnvif.Devices.ServiceCapabilities.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.ServiceCapabilities.html#t:t/0","title":"ExOnvif.Devices.ServiceCapabilities.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Devices.ServiceCapabilities.html#to_struct/1","title":"ExOnvif.Devices.ServiceCapabilities.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.ServiceCapabilities.NetworkCapabilities.html","title":"ExOnvif.Devices.ServiceCapabilities.NetworkCapabilities","type":"module"},{"doc":"","ref":"ExOnvif.Devices.ServiceCapabilities.SecurityCapabilities.html","title":"ExOnvif.Devices.ServiceCapabilities.SecurityCapabilities","type":"module"},{"doc":"","ref":"ExOnvif.Devices.ServiceCapabilities.SystemCapabilities.html","title":"ExOnvif.Devices.ServiceCapabilities.SystemCapabilities","type":"module"},{"doc":"","ref":"ExOnvif.Devices.SystemDateAndTime.html","title":"ExOnvif.Devices.SystemDateAndTime","type":"module"},{"doc":"","ref":"ExOnvif.Devices.SystemDateAndTime.html#changeset/2","title":"ExOnvif.Devices.SystemDateAndTime.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Devices.SystemDateAndTime.html#encode/1","title":"ExOnvif.Devices.SystemDateAndTime.encode/1","type":"function"},{"doc":"Get local camera time as a naive date time.","ref":"ExOnvif.Devices.SystemDateAndTime.html#local_time/1","title":"ExOnvif.Devices.SystemDateAndTime.local_time/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.SystemDateAndTime.html#parse/1","title":"ExOnvif.Devices.SystemDateAndTime.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.SystemDateAndTime.html#t:t/0","title":"ExOnvif.Devices.SystemDateAndTime.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Devices.SystemDateAndTime.html#to_struct/1","title":"ExOnvif.Devices.SystemDateAndTime.to_struct/1","type":"function"},{"doc":"Get utc camera time as `DateTime`.","ref":"ExOnvif.Devices.SystemDateAndTime.html#utc_time/1","title":"ExOnvif.Devices.SystemDateAndTime.utc_time/1","type":"function"},{"doc":"","ref":"ExOnvif.Devices.SystemDateAndTime.LocalDateTime.html","title":"ExOnvif.Devices.SystemDateAndTime.LocalDateTime","type":"module"},{"doc":"","ref":"ExOnvif.Devices.SystemDateAndTime.LocalDateTime.Date.html","title":"ExOnvif.Devices.SystemDateAndTime.LocalDateTime.Date","type":"module"},{"doc":"","ref":"ExOnvif.Devices.SystemDateAndTime.LocalDateTime.Time.html","title":"ExOnvif.Devices.SystemDateAndTime.LocalDateTime.Time","type":"module"},{"doc":"","ref":"ExOnvif.Devices.SystemDateAndTime.TimeZone.html","title":"ExOnvif.Devices.SystemDateAndTime.TimeZone","type":"module"},{"doc":"","ref":"ExOnvif.Devices.SystemDateAndTime.UTCDateTime.html","title":"ExOnvif.Devices.SystemDateAndTime.UTCDateTime","type":"module"},{"doc":"","ref":"ExOnvif.Devices.SystemDateAndTime.UTCDateTime.Date.html","title":"ExOnvif.Devices.SystemDateAndTime.UTCDateTime.Date","type":"module"},{"doc":"","ref":"ExOnvif.Devices.SystemDateAndTime.UTCDateTime.Time.html","title":"ExOnvif.Devices.SystemDateAndTime.UTCDateTime.Time","type":"module"},{"doc":"Scheme describing a pull messages response.","ref":"ExOnvif.Event.Messages.html","title":"ExOnvif.Event.Messages","type":"module"},{"doc":"","ref":"ExOnvif.Event.Messages.html#changeset/2","title":"ExOnvif.Event.Messages.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Event.Messages.html#parse/1","title":"ExOnvif.Event.Messages.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Event.Messages.html#t:t/0","title":"ExOnvif.Event.Messages.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Event.Messages.html#to_struct/1","title":"ExOnvif.Event.Messages.to_struct/1","type":"function"},{"doc":"Scheme describing a notification message.","ref":"ExOnvif.Event.NotificationMessage.html","title":"ExOnvif.Event.NotificationMessage","type":"module"},{"doc":"","ref":"ExOnvif.Event.NotificationMessage.html#changeset/2","title":"ExOnvif.Event.NotificationMessage.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Event.NotificationMessage.html#parse/1","title":"ExOnvif.Event.NotificationMessage.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Event.NotificationMessage.html#t:t/0","title":"ExOnvif.Event.NotificationMessage.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Event.NotificationMessage.html#to_struct/1","title":"ExOnvif.Event.NotificationMessage.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Event.NotificationMessage.Message.html","title":"ExOnvif.Event.NotificationMessage.Message","type":"module"},{"doc":"","ref":"ExOnvif.Event.NotificationMessage.Message.html#t:t/0","title":"ExOnvif.Event.NotificationMessage.Message.t/0","type":"type"},{"doc":"Schema describing a pull point subscription","ref":"ExOnvif.Event.PullPointSubscription.html","title":"ExOnvif.Event.PullPointSubscription","type":"module"},{"doc":"","ref":"ExOnvif.Event.PullPointSubscription.html#changeset/2","title":"ExOnvif.Event.PullPointSubscription.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Event.PullPointSubscription.html#parse/1","title":"ExOnvif.Event.PullPointSubscription.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Event.PullPointSubscription.html#t:t/0","title":"ExOnvif.Event.PullPointSubscription.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Event.PullPointSubscription.html#to_struct/1","title":"ExOnvif.Event.PullPointSubscription.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Event.PullPointSubscription.SubscriptionReference.html","title":"ExOnvif.Event.PullPointSubscription.SubscriptionReference","type":"module"},{"doc":"","ref":"ExOnvif.Event.PullPointSubscription.SubscriptionReference.html#t:t/0","title":"ExOnvif.Event.PullPointSubscription.SubscriptionReference.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Event.PullPointSubscription.SubscriptionReference.ReferenceParameters.html","title":"ExOnvif.Event.PullPointSubscription.SubscriptionReference.ReferenceParameters","type":"module"},{"doc":"","ref":"ExOnvif.Event.PullPointSubscription.SubscriptionReference.ReferenceParameters.html#t:t/0","title":"ExOnvif.Event.PullPointSubscription.SubscriptionReference.ReferenceParameters.t/0","type":"type"},{"doc":"Schema describing the capabilities of the event service","ref":"ExOnvif.Event.ServiceCapabilities.html","title":"ExOnvif.Event.ServiceCapabilities","type":"module"},{"doc":"","ref":"ExOnvif.Event.ServiceCapabilities.html#changeset/2","title":"ExOnvif.Event.ServiceCapabilities.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Event.ServiceCapabilities.html#parse/1","title":"ExOnvif.Event.ServiceCapabilities.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Event.ServiceCapabilities.html#t:t/0","title":"ExOnvif.Event.ServiceCapabilities.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Event.ServiceCapabilities.html#to_struct/1","title":"ExOnvif.Event.ServiceCapabilities.to_struct/1","type":"function"},{"doc":"Optional configuration of the Audio encoder.","ref":"ExOnvif.Media.AudioEncoderConfigurationOptions.html","title":"ExOnvif.Media.AudioEncoderConfigurationOptions","type":"module"},{"doc":"","ref":"ExOnvif.Media.AudioEncoderConfigurationOptions.html#changeset/2","title":"ExOnvif.Media.AudioEncoderConfigurationOptions.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.AudioEncoderConfigurationOptions.html#parse/1","title":"ExOnvif.Media.AudioEncoderConfigurationOptions.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.AudioEncoderConfigurationOptions.html#t:t/0","title":"ExOnvif.Media.AudioEncoderConfigurationOptions.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media.AudioEncoderConfigurationOptions.html#to_struct/1","title":"ExOnvif.Media.AudioEncoderConfigurationOptions.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.AudioEncoderConfigurationOptions.Options.html","title":"ExOnvif.Media.AudioEncoderConfigurationOptions.Options","type":"module"},{"doc":"OSD (On-Screen Display) specification.","ref":"ExOnvif.Media.OSD.html","title":"ExOnvif.Media.OSD","type":"module"},{"doc":"","ref":"ExOnvif.Media.OSD.html#changeset/2","title":"ExOnvif.Media.OSD.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.OSD.html#encode/1","title":"ExOnvif.Media.OSD.encode/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.OSD.html#parse/1","title":"ExOnvif.Media.OSD.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.OSD.html#t:t/0","title":"ExOnvif.Media.OSD.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media.OSD.html#to_struct/1","title":"ExOnvif.Media.OSD.to_struct/1","type":"function"},{"doc":"A schema describing an OSD color.","ref":"ExOnvif.Media.OSD.Color.html","title":"ExOnvif.Media.OSD.Color","type":"module"},{"doc":"","ref":"ExOnvif.Media.OSD.Color.html#changeset/2","title":"ExOnvif.Media.OSD.Color.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.OSD.Color.html#encode/1","title":"ExOnvif.Media.OSD.Color.encode/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.OSD.Color.html#parse/1","title":"ExOnvif.Media.OSD.Color.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.OSD.Color.html#t:t/0","title":"ExOnvif.Media.OSD.Color.t/0","type":"type"},{"doc":"Schema for the color options of the OSD (On-Screen Display) in ExOnvif.","ref":"ExOnvif.Media.OSD.ColorOptions.html","title":"ExOnvif.Media.OSD.ColorOptions","type":"module"},{"doc":"","ref":"ExOnvif.Media.OSD.ColorOptions.html#changeset/2","title":"ExOnvif.Media.OSD.ColorOptions.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.OSD.ColorOptions.html#parse/1","title":"ExOnvif.Media.OSD.ColorOptions.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.OSD.ColorOptions.html#t:t/0","title":"ExOnvif.Media.OSD.ColorOptions.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media.OSD.ColorOptions.Color.html","title":"ExOnvif.Media.OSD.ColorOptions.Color","type":"module"},{"doc":"","ref":"ExOnvif.Media.OSD.ColorOptions.Color.ColorSpaceRange.html","title":"ExOnvif.Media.OSD.ColorOptions.Color.ColorSpaceRange","type":"module"},{"doc":"","ref":"ExOnvif.Media.OSD.Image.html","title":"ExOnvif.Media.OSD.Image","type":"module"},{"doc":"","ref":"ExOnvif.Media.OSD.Position.html","title":"ExOnvif.Media.OSD.Position","type":"module"},{"doc":"","ref":"ExOnvif.Media.OSD.TextString.html","title":"ExOnvif.Media.OSD.TextString","type":"module"},{"doc":"OSD (On-Screen Display) Options specification.","ref":"ExOnvif.Media.OSDOptions.html","title":"ExOnvif.Media.OSDOptions","type":"module"},{"doc":"","ref":"ExOnvif.Media.OSDOptions.html#changeset/2","title":"ExOnvif.Media.OSDOptions.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.OSDOptions.html#parse/1","title":"ExOnvif.Media.OSDOptions.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.OSDOptions.html#t:t/0","title":"ExOnvif.Media.OSDOptions.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media.OSDOptions.html#to_struct/1","title":"ExOnvif.Media.OSDOptions.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.OSDOptions.ImageOption.html","title":"ExOnvif.Media.OSDOptions.ImageOption","type":"module"},{"doc":"","ref":"ExOnvif.Media.OSDOptions.MaximumNumberOfOSDs.html","title":"ExOnvif.Media.OSDOptions.MaximumNumberOfOSDs","type":"module"},{"doc":"","ref":"ExOnvif.Media.OSDOptions.TextOption.html","title":"ExOnvif.Media.OSDOptions.TextOption","type":"module"},{"doc":"A media profile, or a standard definition of media configurations for video","ref":"ExOnvif.Media.Profile.html","title":"ExOnvif.Media.Profile","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.html#changeset/2","title":"ExOnvif.Media.Profile.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.html#parse/1","title":"ExOnvif.Media.Profile.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.html#t:t/0","title":"ExOnvif.Media.Profile.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media.Profile.html#to_json/1","title":"ExOnvif.Media.Profile.to_json/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.html#to_struct/1","title":"ExOnvif.Media.Profile.to_struct/1","type":"function"},{"doc":"Indication which AnalyticsModules shall output metadata. Note that the streaming behavior is undefined if the list\nincludes items that are not part of the associated AnalyticsConfiguration.","ref":"ExOnvif.Media.Profile.AnalyticsEngineConfiguration.html","title":"ExOnvif.Media.Profile.AnalyticsEngineConfiguration","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.AnalyticsEngineConfiguration.html#changeset/2","title":"ExOnvif.Media.Profile.AnalyticsEngineConfiguration.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.AnalyticsEngineConfiguration.html#parse/1","title":"ExOnvif.Media.Profile.AnalyticsEngineConfiguration.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.AnalyticsEngineConfiguration.html#t:t/0","title":"ExOnvif.Media.Profile.AnalyticsEngineConfiguration.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media.Profile.AnalyticsEngineConfiguration.html#to_struct/1","title":"ExOnvif.Media.Profile.AnalyticsEngineConfiguration.to_struct/1","type":"function"},{"doc":"Optional configuration of the Audio encoder.","ref":"ExOnvif.Media.Profile.AudioEncoderConfiguration.html","title":"ExOnvif.Media.Profile.AudioEncoderConfiguration","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.AudioEncoderConfiguration.html#changeset/2","title":"ExOnvif.Media.Profile.AudioEncoderConfiguration.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.AudioEncoderConfiguration.html#encode/2","title":"ExOnvif.Media.Profile.AudioEncoderConfiguration.encode/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.AudioEncoderConfiguration.html#parse/1","title":"ExOnvif.Media.Profile.AudioEncoderConfiguration.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.AudioEncoderConfiguration.html#t:t/0","title":"ExOnvif.Media.Profile.AudioEncoderConfiguration.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media.Profile.AudioEncoderConfiguration.html#to_struct/1","title":"ExOnvif.Media.Profile.AudioEncoderConfiguration.to_struct/1","type":"function"},{"doc":"AudioSourceConfiguration schema for Media Ver10","ref":"ExOnvif.Media.Profile.AudioSourceConfiguration.html","title":"ExOnvif.Media.Profile.AudioSourceConfiguration","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.AudioSourceConfiguration.html#changeset/2","title":"ExOnvif.Media.Profile.AudioSourceConfiguration.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.AudioSourceConfiguration.html#parse/1","title":"ExOnvif.Media.Profile.AudioSourceConfiguration.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.AudioSourceConfiguration.html#t:t/0","title":"ExOnvif.Media.Profile.AudioSourceConfiguration.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media.Profile.AudioSourceConfiguration.html#to_struct/1","title":"ExOnvif.Media.Profile.AudioSourceConfiguration.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.Extension.html","title":"ExOnvif.Media.Profile.Extension","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.Extension.AudioDecoderConfiguration.html","title":"ExOnvif.Media.Profile.Extension.AudioDecoderConfiguration","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.Extension.AudioOutputConfiguration.html","title":"ExOnvif.Media.Profile.Extension.AudioOutputConfiguration","type":"module"},{"doc":"Optional configuration of the metadata stream.","ref":"ExOnvif.Media.Profile.MetadataConfiguration.html","title":"ExOnvif.Media.Profile.MetadataConfiguration","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.MetadataConfiguration.html#changeset/2","title":"ExOnvif.Media.Profile.MetadataConfiguration.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.MetadataConfiguration.html#parse/1","title":"ExOnvif.Media.Profile.MetadataConfiguration.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.MetadataConfiguration.html#t:t/0","title":"ExOnvif.Media.Profile.MetadataConfiguration.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media.Profile.MetadataConfiguration.html#to_struct/1","title":"ExOnvif.Media.Profile.MetadataConfiguration.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.MetadataConfiguration.PtzStatus.html","title":"ExOnvif.Media.Profile.MetadataConfiguration.PtzStatus","type":"module"},{"doc":"MulticastConfiguration for Media Ver10","ref":"ExOnvif.Media.Profile.MulticastConfiguration.html","title":"ExOnvif.Media.Profile.MulticastConfiguration","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.MulticastConfiguration.html#changeset/2","title":"ExOnvif.Media.Profile.MulticastConfiguration.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.MulticastConfiguration.html#encode/1","title":"ExOnvif.Media.Profile.MulticastConfiguration.encode/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.MulticastConfiguration.html#parse/1","title":"ExOnvif.Media.Profile.MulticastConfiguration.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.MulticastConfiguration.html#t:t/0","title":"ExOnvif.Media.Profile.MulticastConfiguration.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media.Profile.MulticastConfiguration.html#to_struct/1","title":"ExOnvif.Media.Profile.MulticastConfiguration.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.MulticastConfiguration.IpAddress.html","title":"ExOnvif.Media.Profile.MulticastConfiguration.IpAddress","type":"module"},{"doc":"Optional configuration of the pan tilt zoom unit.","ref":"ExOnvif.Media.Profile.PtzConfiguration.html","title":"ExOnvif.Media.Profile.PtzConfiguration","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.PtzConfiguration.html#t:t/0","title":"ExOnvif.Media.Profile.PtzConfiguration.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media.Profile.PtzConfiguration.DefaultPtzSpeed.html","title":"ExOnvif.Media.Profile.PtzConfiguration.DefaultPtzSpeed","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.PtzConfiguration.Extension.html","title":"ExOnvif.Media.Profile.PtzConfiguration.Extension","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.PtzConfiguration.Extension.PtControlDirection.html","title":"ExOnvif.Media.Profile.PtzConfiguration.Extension.PtControlDirection","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.PtzConfiguration.Extension.PtControlDirection.EFlip.html","title":"ExOnvif.Media.Profile.PtzConfiguration.Extension.PtControlDirection.EFlip","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.PtzConfiguration.Extension.PtControlDirection.Reverse.html","title":"ExOnvif.Media.Profile.PtzConfiguration.Extension.PtControlDirection.Reverse","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.PtzConfiguration.PanTiltLimits.html","title":"ExOnvif.Media.Profile.PtzConfiguration.PanTiltLimits","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.PtzConfiguration.PanTiltLimits.Range.html","title":"ExOnvif.Media.Profile.PtzConfiguration.PanTiltLimits.Range","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.PtzConfiguration.ZoomLimits.html","title":"ExOnvif.Media.Profile.PtzConfiguration.ZoomLimits","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.PtzConfiguration.ZoomLimits.Range.html","title":"ExOnvif.Media.Profile.PtzConfiguration.ZoomLimits.Range","type":"module"},{"doc":"This element contains a list of Analytics configurations.","ref":"ExOnvif.Media.Profile.VideoAnalyticsConfiguration.html","title":"ExOnvif.Media.Profile.VideoAnalyticsConfiguration","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoAnalyticsConfiguration.html#changeset/2","title":"ExOnvif.Media.Profile.VideoAnalyticsConfiguration.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoAnalyticsConfiguration.html#parse/1","title":"ExOnvif.Media.Profile.VideoAnalyticsConfiguration.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoAnalyticsConfiguration.html#t:t/0","title":"ExOnvif.Media.Profile.VideoAnalyticsConfiguration.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoAnalyticsConfiguration.html#to_struct/1","title":"ExOnvif.Media.Profile.VideoAnalyticsConfiguration.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoAnalyticsConfiguration.RuleEngineConfiguration.html","title":"ExOnvif.Media.Profile.VideoAnalyticsConfiguration.RuleEngineConfiguration","type":"module"},{"doc":"Configurations for the video encoding","ref":"ExOnvif.Media.Profile.VideoEncoderConfiguration.html","title":"ExOnvif.Media.Profile.VideoEncoderConfiguration","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoEncoderConfiguration.html#changeset/2","title":"ExOnvif.Media.Profile.VideoEncoderConfiguration.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoEncoderConfiguration.html#encode/2","title":"ExOnvif.Media.Profile.VideoEncoderConfiguration.encode/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoEncoderConfiguration.html#parse/1","title":"ExOnvif.Media.Profile.VideoEncoderConfiguration.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoEncoderConfiguration.html#t:t/0","title":"ExOnvif.Media.Profile.VideoEncoderConfiguration.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoEncoderConfiguration.html#to_struct/1","title":"ExOnvif.Media.Profile.VideoEncoderConfiguration.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoEncoderConfiguration.H264Configuration.html","title":"ExOnvif.Media.Profile.VideoEncoderConfiguration.H264Configuration","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoEncoderConfiguration.Mpeg4Configuration.html","title":"ExOnvif.Media.Profile.VideoEncoderConfiguration.Mpeg4Configuration","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoEncoderConfiguration.RateControl.html","title":"ExOnvif.Media.Profile.VideoEncoderConfiguration.RateControl","type":"module"},{"doc":"Optional configuration of the Video input.","ref":"ExOnvif.Media.Profile.VideoSourceConfiguration.html","title":"ExOnvif.Media.Profile.VideoSourceConfiguration","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoSourceConfiguration.html#changeset/2","title":"ExOnvif.Media.Profile.VideoSourceConfiguration.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoSourceConfiguration.html#parse/1","title":"ExOnvif.Media.Profile.VideoSourceConfiguration.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoSourceConfiguration.html#t:t/0","title":"ExOnvif.Media.Profile.VideoSourceConfiguration.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoSourceConfiguration.html#to_struct/1","title":"ExOnvif.Media.Profile.VideoSourceConfiguration.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoSourceConfiguration.Bounds.html","title":"ExOnvif.Media.Profile.VideoSourceConfiguration.Bounds","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoSourceConfiguration.Extension.html","title":"ExOnvif.Media.Profile.VideoSourceConfiguration.Extension","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoSourceConfiguration.Extension.Rotate.html","title":"ExOnvif.Media.Profile.VideoSourceConfiguration.Extension.Rotate","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.html","title":"ExOnvif.Media.Profile.VideoSourceConfiguration.Extension.Rotate.Extension","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.LensDescription.html","title":"ExOnvif.Media.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.LensDescription","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.LensDescription.LensOffset.html","title":"ExOnvif.Media.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.LensDescription.LensOffset","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.LensDescription.Projection.html","title":"ExOnvif.Media.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.LensDescription.Projection","type":"module"},{"doc":"","ref":"ExOnvif.Media.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.SceneOrientation.html","title":"ExOnvif.Media.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.SceneOrientation","type":"module"},{"doc":"Schema describing the capabilities of media service.","ref":"ExOnvif.Media.ServiceCapabilities.html","title":"ExOnvif.Media.ServiceCapabilities","type":"module"},{"doc":"","ref":"ExOnvif.Media.ServiceCapabilities.html#changeset/2","title":"ExOnvif.Media.ServiceCapabilities.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.ServiceCapabilities.html#parse/1","title":"ExOnvif.Media.ServiceCapabilities.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.ServiceCapabilities.html#t:t/0","title":"ExOnvif.Media.ServiceCapabilities.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media.ServiceCapabilities.html#to_struct/1","title":"ExOnvif.Media.ServiceCapabilities.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.ServiceCapabilities.StreamingCapabilities.html","title":"ExOnvif.Media.ServiceCapabilities.StreamingCapabilities","type":"module"},{"doc":"Optional configuration of the Video encoder.","ref":"ExOnvif.Media.VideoEncoderConfigurationOptions.html","title":"ExOnvif.Media.VideoEncoderConfigurationOptions","type":"module"},{"doc":"","ref":"ExOnvif.Media.VideoEncoderConfigurationOptions.html#changeset/2","title":"ExOnvif.Media.VideoEncoderConfigurationOptions.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.VideoEncoderConfigurationOptions.html#parse/1","title":"ExOnvif.Media.VideoEncoderConfigurationOptions.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.VideoEncoderConfigurationOptions.html#t:t/0","title":"ExOnvif.Media.VideoEncoderConfigurationOptions.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media.VideoEncoderConfigurationOptions.html#to_json/1","title":"ExOnvif.Media.VideoEncoderConfigurationOptions.to_json/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.VideoEncoderConfigurationOptions.html#to_struct/1","title":"ExOnvif.Media.VideoEncoderConfigurationOptions.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.VideoEncoderConfigurationOptions.Extension.html","title":"ExOnvif.Media.VideoEncoderConfigurationOptions.Extension","type":"module"},{"doc":"","ref":"ExOnvif.Media.VideoEncoderConfigurationOptions.Extension.H264Options.html","title":"ExOnvif.Media.VideoEncoderConfigurationOptions.Extension.H264Options","type":"module"},{"doc":"","ref":"ExOnvif.Media.VideoEncoderConfigurationOptions.Extension.JpegOptions.html","title":"ExOnvif.Media.VideoEncoderConfigurationOptions.Extension.JpegOptions","type":"module"},{"doc":"","ref":"ExOnvif.Media.VideoEncoderConfigurationOptions.Extension.Mpeg4Options.html","title":"ExOnvif.Media.VideoEncoderConfigurationOptions.Extension.Mpeg4Options","type":"module"},{"doc":"","ref":"ExOnvif.Media.VideoEncoderConfigurationOptions.H264Options.html","title":"ExOnvif.Media.VideoEncoderConfigurationOptions.H264Options","type":"module"},{"doc":"","ref":"ExOnvif.Media.VideoEncoderConfigurationOptions.JpegOptions.html","title":"ExOnvif.Media.VideoEncoderConfigurationOptions.JpegOptions","type":"module"},{"doc":"","ref":"ExOnvif.Media.VideoEncoderConfigurationOptions.Mpeg4Options.html","title":"ExOnvif.Media.VideoEncoderConfigurationOptions.Mpeg4Options","type":"module"},{"doc":"Schema describing the resolution of a video stream.","ref":"ExOnvif.Media.VideoResolution.html","title":"ExOnvif.Media.VideoResolution","type":"module"},{"doc":"","ref":"ExOnvif.Media.VideoResolution.html#changeset/2","title":"ExOnvif.Media.VideoResolution.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media.VideoResolution.html#encode/1","title":"ExOnvif.Media.VideoResolution.encode/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.VideoResolution.html#parse/1","title":"ExOnvif.Media.VideoResolution.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media.VideoResolution.html#t:t/0","title":"ExOnvif.Media.VideoResolution.t/0","type":"type"},{"doc":"Schema describing a request to add a configuration to the media service.","ref":"ExOnvif.Media2.AddConfiguration.html","title":"ExOnvif.Media2.AddConfiguration","type":"module"},{"doc":"","ref":"ExOnvif.Media2.AddConfiguration.html#changeset/2","title":"ExOnvif.Media2.AddConfiguration.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media2.AddConfiguration.html#encode/1","title":"ExOnvif.Media2.AddConfiguration.encode/1","type":"function"},{"doc":"","ref":"ExOnvif.Media2.AddConfiguration.html#t:t/0","title":"ExOnvif.Media2.AddConfiguration.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media2.AddConfiguration.Configuration.html","title":"ExOnvif.Media2.AddConfiguration.Configuration","type":"module"},{"doc":"","ref":"ExOnvif.Media2.AddConfiguration.Configuration.html#t:t/0","title":"ExOnvif.Media2.AddConfiguration.Configuration.t/0","type":"type"},{"doc":"A media profile","ref":"ExOnvif.Media2.Profile.html","title":"ExOnvif.Media2.Profile","type":"module"},{"doc":"","ref":"ExOnvif.Media2.Profile.html#changeset/2","title":"ExOnvif.Media2.Profile.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media2.Profile.html#parse/1","title":"ExOnvif.Media2.Profile.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media2.Profile.html#t:t/0","title":"ExOnvif.Media2.Profile.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media2.Profile.html#to_struct/1","title":"ExOnvif.Media2.Profile.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Media2.Profile.Extension.html","title":"ExOnvif.Media2.Profile.Extension","type":"module"},{"doc":"","ref":"ExOnvif.Media2.Profile.Extension.AudioDecoderConfiguration.html","title":"ExOnvif.Media2.Profile.Extension.AudioDecoderConfiguration","type":"module"},{"doc":"","ref":"ExOnvif.Media2.Profile.Extension.AudioOutputConfiguration.html","title":"ExOnvif.Media2.Profile.Extension.AudioOutputConfiguration","type":"module"},{"doc":"VideoEncoder schema for Media Ver20","ref":"ExOnvif.Media2.Profile.VideoEncoder.html","title":"ExOnvif.Media2.Profile.VideoEncoder","type":"module"},{"doc":"","ref":"ExOnvif.Media2.Profile.VideoEncoder.html#changeset/2","title":"ExOnvif.Media2.Profile.VideoEncoder.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media2.Profile.VideoEncoder.html#encode/1","title":"ExOnvif.Media2.Profile.VideoEncoder.encode/1","type":"function"},{"doc":"","ref":"ExOnvif.Media2.Profile.VideoEncoder.html#parse/1","title":"ExOnvif.Media2.Profile.VideoEncoder.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media2.Profile.VideoEncoder.html#t:t/0","title":"ExOnvif.Media2.Profile.VideoEncoder.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media2.Profile.VideoEncoder.html#to_struct/1","title":"ExOnvif.Media2.Profile.VideoEncoder.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Media2.Profile.VideoEncoder.RateControl.html","title":"ExOnvif.Media2.Profile.VideoEncoder.RateControl","type":"module"},{"doc":"Schema for the service capabilities of the ONVIF Media2 service.","ref":"ExOnvif.Media2.ServiceCapabilities.html","title":"ExOnvif.Media2.ServiceCapabilities","type":"module"},{"doc":"","ref":"ExOnvif.Media2.ServiceCapabilities.html#changeset/2","title":"ExOnvif.Media2.ServiceCapabilities.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media2.ServiceCapabilities.html#parse/1","title":"ExOnvif.Media2.ServiceCapabilities.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media2.ServiceCapabilities.html#t:t/0","title":"ExOnvif.Media2.ServiceCapabilities.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media2.ServiceCapabilities.html#to_struct/1","title":"ExOnvif.Media2.ServiceCapabilities.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Media2.ServiceCapabilities.ProfileCapabilities.html","title":"ExOnvif.Media2.ServiceCapabilities.ProfileCapabilities","type":"module"},{"doc":"","ref":"ExOnvif.Media2.ServiceCapabilities.StreamingCapabilities.html","title":"ExOnvif.Media2.ServiceCapabilities.StreamingCapabilities","type":"module"},{"doc":"Available options for video encoder configuration","ref":"ExOnvif.Media2.VideoEncoderConfigurationOption.html","title":"ExOnvif.Media2.VideoEncoderConfigurationOption","type":"module"},{"doc":"","ref":"ExOnvif.Media2.VideoEncoderConfigurationOption.html#changeset/2","title":"ExOnvif.Media2.VideoEncoderConfigurationOption.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Media2.VideoEncoderConfigurationOption.html#parse/1","title":"ExOnvif.Media2.VideoEncoderConfigurationOption.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Media2.VideoEncoderConfigurationOption.html#t:t/0","title":"ExOnvif.Media2.VideoEncoderConfigurationOption.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Media2.VideoEncoderConfigurationOption.html#to_struct/1","title":"ExOnvif.Media2.VideoEncoderConfigurationOption.to_struct/1","type":"function"},{"doc":"Schema describing the absolute move request to the PTZ service.","ref":"ExOnvif.PTZ.AbsoluteMove.html","title":"ExOnvif.PTZ.AbsoluteMove","type":"module"},{"doc":"","ref":"ExOnvif.PTZ.AbsoluteMove.html#changeset/2","title":"ExOnvif.PTZ.AbsoluteMove.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.PTZ.AbsoluteMove.html#encode/1","title":"ExOnvif.PTZ.AbsoluteMove.encode/1","type":"function"},{"doc":"Creates a new absolute move request.","ref":"ExOnvif.PTZ.AbsoluteMove.html#new/3","title":"ExOnvif.PTZ.AbsoluteMove.new/3","type":"function"},{"doc":"- `profile_token` - The token of the profile to move.\n  - `position` - The position to move to, represented as a `Vector`.\n  - `speed` - The speed of the move, represented as a `Vector`. Optional.","ref":"ExOnvif.PTZ.AbsoluteMove.html#new/3-parameters","title":"Parameters - ExOnvif.PTZ.AbsoluteMove.new/3","type":"function"},{"doc":"","ref":"ExOnvif.PTZ.AbsoluteMove.html#t:t/0","title":"ExOnvif.PTZ.AbsoluteMove.t/0","type":"type"},{"doc":"","ref":"ExOnvif.PTZ.AbsoluteMove.html#t:vector/0","title":"ExOnvif.PTZ.AbsoluteMove.vector/0","type":"type"},{"doc":"Module describing a PTZ node.","ref":"ExOnvif.PTZ.Node.html","title":"ExOnvif.PTZ.Node","type":"module"},{"doc":"","ref":"ExOnvif.PTZ.Node.html#changeset/2","title":"ExOnvif.PTZ.Node.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.PTZ.Node.html#parse/1","title":"ExOnvif.PTZ.Node.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.PTZ.Node.html#t:t/0","title":"ExOnvif.PTZ.Node.t/0","type":"type"},{"doc":"","ref":"ExOnvif.PTZ.Node.html#to_struct/1","title":"ExOnvif.PTZ.Node.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.PTZ.Node.Extension.html","title":"ExOnvif.PTZ.Node.Extension","type":"module"},{"doc":"","ref":"ExOnvif.PTZ.Node.Extension.SupportedPresetTour.html","title":"ExOnvif.PTZ.Node.Extension.SupportedPresetTour","type":"module"},{"doc":"","ref":"ExOnvif.PTZ.Node.SupportedPTZSpaces.html","title":"ExOnvif.PTZ.Node.SupportedPTZSpaces","type":"module"},{"doc":"Struct representing the service capabilities of a PTZ device.","ref":"ExOnvif.PTZ.ServiceCapabilities.html","title":"ExOnvif.PTZ.ServiceCapabilities","type":"module"},{"doc":"","ref":"ExOnvif.PTZ.ServiceCapabilities.html#changeset/2","title":"ExOnvif.PTZ.ServiceCapabilities.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.PTZ.ServiceCapabilities.html#parse/1","title":"ExOnvif.PTZ.ServiceCapabilities.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.PTZ.ServiceCapabilities.html#t:t/0","title":"ExOnvif.PTZ.ServiceCapabilities.t/0","type":"type"},{"doc":"","ref":"ExOnvif.PTZ.ServiceCapabilities.html#to_struct/1","title":"ExOnvif.PTZ.ServiceCapabilities.to_struct/1","type":"function"},{"doc":"Module describing PTZ Status schema","ref":"ExOnvif.PTZ.Status.html","title":"ExOnvif.PTZ.Status","type":"module"},{"doc":"","ref":"ExOnvif.PTZ.Status.html#changeset/2","title":"ExOnvif.PTZ.Status.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.PTZ.Status.html#parse/1","title":"ExOnvif.PTZ.Status.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.PTZ.Status.html#t:t/0","title":"ExOnvif.PTZ.Status.t/0","type":"type"},{"doc":"","ref":"ExOnvif.PTZ.Status.html#to_struct/1","title":"ExOnvif.PTZ.Status.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.PTZ.Status.MoveStatus.html","title":"ExOnvif.PTZ.Status.MoveStatus","type":"module"},{"doc":"PTZ speed/vector schema","ref":"ExOnvif.PTZ.Vector.html","title":"ExOnvif.PTZ.Vector","type":"module"},{"doc":"","ref":"ExOnvif.PTZ.Vector.html#changeset/2","title":"ExOnvif.PTZ.Vector.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.PTZ.Vector.html#encode/1","title":"ExOnvif.PTZ.Vector.encode/1","type":"function"},{"doc":"","ref":"ExOnvif.PTZ.Vector.html#new/3","title":"ExOnvif.PTZ.Vector.new/3","type":"function"},{"doc":"","ref":"ExOnvif.PTZ.Vector.html#parse/1","title":"ExOnvif.PTZ.Vector.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.PTZ.Vector.html#t:t/0","title":"ExOnvif.PTZ.Vector.t/0","type":"type"},{"doc":"","ref":"ExOnvif.PTZ.Vector.PanTilt.html","title":"ExOnvif.PTZ.Vector.PanTilt","type":"module"},{"doc":"Schema describing a recording job configuration.","ref":"ExOnvif.Recording.JobConfiguration.html","title":"ExOnvif.Recording.JobConfiguration","type":"module"},{"doc":"","ref":"ExOnvif.Recording.JobConfiguration.html#changeset/2","title":"ExOnvif.Recording.JobConfiguration.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Recording.JobConfiguration.html#encode/1","title":"ExOnvif.Recording.JobConfiguration.encode/1","type":"function"},{"doc":"","ref":"ExOnvif.Recording.JobConfiguration.html#parse/1","title":"ExOnvif.Recording.JobConfiguration.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Recording.JobConfiguration.html#t:t/0","title":"ExOnvif.Recording.JobConfiguration.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Recording.JobConfiguration.html#to_struct/1","title":"ExOnvif.Recording.JobConfiguration.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Recording.JobConfiguration.Source.html","title":"ExOnvif.Recording.JobConfiguration.Source","type":"module"},{"doc":"","ref":"ExOnvif.Recording.JobConfiguration.Source.SourceToken.html","title":"ExOnvif.Recording.JobConfiguration.Source.SourceToken","type":"module"},{"doc":"","ref":"ExOnvif.Recording.JobConfiguration.Source.Tracks.html","title":"ExOnvif.Recording.JobConfiguration.Source.Tracks","type":"module"},{"doc":"ExOnvif.Recording.Recordings schema.","ref":"ExOnvif.Recording.Recording.html","title":"ExOnvif.Recording.Recording","type":"module"},{"doc":"","ref":"ExOnvif.Recording.Recording.html#changeset/2","title":"ExOnvif.Recording.Recording.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Recording.Recording.html#parse/1","title":"ExOnvif.Recording.Recording.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Recording.Recording.html#t:t/0","title":"ExOnvif.Recording.Recording.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Recording.Recording.html#to_struct/1","title":"ExOnvif.Recording.Recording.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Recording.Recording.Tracks.html","title":"ExOnvif.Recording.Recording.Tracks","type":"module"},{"doc":"","ref":"ExOnvif.Recording.Recording.Tracks.Track.html","title":"ExOnvif.Recording.Recording.Tracks.Track","type":"module"},{"doc":"","ref":"ExOnvif.Recording.Recording.Tracks.Track.Configuration.html","title":"ExOnvif.Recording.Recording.Tracks.Track.Configuration","type":"module"},{"doc":"Schema describing recording configuration.","ref":"ExOnvif.Recording.RecordingConfiguration.html","title":"ExOnvif.Recording.RecordingConfiguration","type":"module"},{"doc":"","ref":"ExOnvif.Recording.RecordingConfiguration.html#changeset/2","title":"ExOnvif.Recording.RecordingConfiguration.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Recording.RecordingConfiguration.html#encode/1","title":"ExOnvif.Recording.RecordingConfiguration.encode/1","type":"function"},{"doc":"","ref":"ExOnvif.Recording.RecordingConfiguration.html#parse/1","title":"ExOnvif.Recording.RecordingConfiguration.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Recording.RecordingConfiguration.html#t:t/0","title":"ExOnvif.Recording.RecordingConfiguration.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Recording.RecordingConfiguration.html#to_struct/1","title":"ExOnvif.Recording.RecordingConfiguration.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Recording.RecordingConfiguration.Source.html","title":"ExOnvif.Recording.RecordingConfiguration.Source","type":"module"},{"doc":"Recordings.","ref":"ExOnvif.Recording.RecordingJob.html","title":"ExOnvif.Recording.RecordingJob","type":"module"},{"doc":"","ref":"ExOnvif.Recording.RecordingJob.html#changeset/2","title":"ExOnvif.Recording.RecordingJob.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Recording.RecordingJob.html#parse/1","title":"ExOnvif.Recording.RecordingJob.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Recording.RecordingJob.html#t:t/0","title":"ExOnvif.Recording.RecordingJob.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Recording.RecordingJob.html#to_struct/1","title":"ExOnvif.Recording.RecordingJob.to_struct/1","type":"function"},{"doc":"Struct representing recording's service capabilities.","ref":"ExOnvif.Recording.ServiceCapabilities.html","title":"ExOnvif.Recording.ServiceCapabilities","type":"module"},{"doc":"","ref":"ExOnvif.Recording.ServiceCapabilities.html#changeset/2","title":"ExOnvif.Recording.ServiceCapabilities.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Recording.ServiceCapabilities.html#parse/1","title":"ExOnvif.Recording.ServiceCapabilities.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Recording.ServiceCapabilities.html#t:t/0","title":"ExOnvif.Recording.ServiceCapabilities.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Recording.ServiceCapabilities.html#to_struct/1","title":"ExOnvif.Recording.ServiceCapabilities.to_struct/1","type":"function"},{"doc":"Schema describing the capabilities of the Replay service.","ref":"ExOnvif.Replay.ServiceCapabilities.html","title":"ExOnvif.Replay.ServiceCapabilities","type":"module"},{"doc":"","ref":"ExOnvif.Replay.ServiceCapabilities.html#changeset/2","title":"ExOnvif.Replay.ServiceCapabilities.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Replay.ServiceCapabilities.html#parse/1","title":"ExOnvif.Replay.ServiceCapabilities.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Replay.ServiceCapabilities.html#t:t/0","title":"ExOnvif.Replay.ServiceCapabilities.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Replay.ServiceCapabilities.html#to_struct/1","title":"ExOnvif.Replay.ServiceCapabilities.to_struct/1","type":"function"},{"doc":"Module describing a float range.","ref":"ExOnvif.Schemas.FloatRange.html","title":"ExOnvif.Schemas.FloatRange","type":"module"},{"doc":"","ref":"ExOnvif.Schemas.FloatRange.html#changeset/2","title":"ExOnvif.Schemas.FloatRange.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Schemas.FloatRange.html#parse/1","title":"ExOnvif.Schemas.FloatRange.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Schemas.FloatRange.html#t:t/0","title":"ExOnvif.Schemas.FloatRange.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Schemas.FloatRange.html#to_xml/1","title":"ExOnvif.Schemas.FloatRange.to_xml/1","type":"function"},{"doc":"Module describing an int range.","ref":"ExOnvif.Schemas.IntRange.html","title":"ExOnvif.Schemas.IntRange","type":"module"},{"doc":"","ref":"ExOnvif.Schemas.IntRange.html#changeset/2","title":"ExOnvif.Schemas.IntRange.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Schemas.IntRange.html#parse/1","title":"ExOnvif.Schemas.IntRange.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Schemas.IntRange.html#t:t/0","title":"ExOnvif.Schemas.IntRange.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Schemas.IntRange.html#to_xml/1","title":"ExOnvif.Schemas.IntRange.to_xml/1","type":"function"},{"doc":"Schema describing metadata streams.","ref":"ExOnvif.Schemas.MetadataStream.html","title":"ExOnvif.Schemas.MetadataStream","type":"module"},{"doc":"","ref":"ExOnvif.Schemas.MetadataStream.html#changeset/2","title":"ExOnvif.Schemas.MetadataStream.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Schemas.MetadataStream.html#parse/1","title":"ExOnvif.Schemas.MetadataStream.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Schemas.MetadataStream.html#t:t/0","title":"ExOnvif.Schemas.MetadataStream.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Schemas.MetadataStream.html#to_struct/1","title":"ExOnvif.Schemas.MetadataStream.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Schemas.MetadataStream.Event.html","title":"ExOnvif.Schemas.MetadataStream.Event","type":"module"},{"doc":"","ref":"ExOnvif.Schemas.MetadataStream.Event.html#t:t/0","title":"ExOnvif.Schemas.MetadataStream.Event.t/0","type":"type"},{"doc":"Schema describing a simple item.","ref":"ExOnvif.Schemas.SimpleItem.html","title":"ExOnvif.Schemas.SimpleItem","type":"module"},{"doc":"","ref":"ExOnvif.Schemas.SimpleItem.html#changeset/2","title":"ExOnvif.Schemas.SimpleItem.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Schemas.SimpleItem.html#parse/1","title":"ExOnvif.Schemas.SimpleItem.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Schemas.SimpleItem.html#t:t/0","title":"ExOnvif.Schemas.SimpleItem.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Schemas.SimpleItem.html#to_struct/1","title":"ExOnvif.Schemas.SimpleItem.to_struct/1","type":"function"},{"doc":"Module describing a 1D space.","ref":"ExOnvif.Schemas.Space1DDescription.html","title":"ExOnvif.Schemas.Space1DDescription","type":"module"},{"doc":"","ref":"ExOnvif.Schemas.Space1DDescription.html#changeset/2","title":"ExOnvif.Schemas.Space1DDescription.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Schemas.Space1DDescription.html#parse/1","title":"ExOnvif.Schemas.Space1DDescription.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Schemas.Space1DDescription.html#t:t/0","title":"ExOnvif.Schemas.Space1DDescription.t/0","type":"type"},{"doc":"Module describing a 2D space.","ref":"ExOnvif.Schemas.Space2DDescription.html","title":"ExOnvif.Schemas.Space2DDescription","type":"module"},{"doc":"","ref":"ExOnvif.Schemas.Space2DDescription.html#changeset/2","title":"ExOnvif.Schemas.Space2DDescription.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Schemas.Space2DDescription.html#parse/1","title":"ExOnvif.Schemas.Space2DDescription.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Schemas.Space2DDescription.html#t:t/0","title":"ExOnvif.Schemas.Space2DDescription.t/0","type":"type"},{"doc":"Schema describing a find events request.","ref":"ExOnvif.Search.FindEvents.html","title":"ExOnvif.Search.FindEvents","type":"module"},{"doc":"","ref":"ExOnvif.Search.FindEvents.html#changeset/2","title":"ExOnvif.Search.FindEvents.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Search.FindEvents.html#encode/1","title":"ExOnvif.Search.FindEvents.encode/1","type":"function"},{"doc":"","ref":"ExOnvif.Search.FindEvents.html#t:t/0","title":"ExOnvif.Search.FindEvents.t/0","type":"type"},{"doc":"A module describing results from `ExOnvif.Search.get_recording_search_results/2`.","ref":"ExOnvif.Search.FindRecordingResult.html","title":"ExOnvif.Search.FindRecordingResult","type":"module"},{"doc":"","ref":"ExOnvif.Search.FindRecordingResult.html#parse/1","title":"ExOnvif.Search.FindRecordingResult.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Search.FindRecordingResult.html#t:t/0","title":"ExOnvif.Search.FindRecordingResult.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Search.FindRecordingResult.html#to_struct/1","title":"ExOnvif.Search.FindRecordingResult.to_struct/1","type":"function"},{"doc":"Module describing the FindRecordings schema.","ref":"ExOnvif.Search.FindRecordings.html","title":"ExOnvif.Search.FindRecordings","type":"module"},{"doc":"","ref":"ExOnvif.Search.FindRecordings.html#changeset/2","title":"ExOnvif.Search.FindRecordings.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Search.FindRecordings.html#encode/1","title":"ExOnvif.Search.FindRecordings.encode/1","type":"function"},{"doc":"","ref":"ExOnvif.Search.FindRecordings.html#t:t/0","title":"ExOnvif.Search.FindRecordings.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Search.FindRecordings.html#to_struct/1","title":"ExOnvif.Search.FindRecordings.to_struct/1","type":"function"},{"doc":"Module describing the request to `ExOnvif.Search.GetRecordingSearchResults`.","ref":"ExOnvif.Search.GetRecordingSearchResults.html","title":"ExOnvif.Search.GetRecordingSearchResults","type":"module"},{"doc":"","ref":"ExOnvif.Search.GetRecordingSearchResults.html#changeset/2","title":"ExOnvif.Search.GetRecordingSearchResults.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Search.GetRecordingSearchResults.html#encode/1","title":"ExOnvif.Search.GetRecordingSearchResults.encode/1","type":"function"},{"doc":"","ref":"ExOnvif.Search.GetRecordingSearchResults.html#t:t/0","title":"ExOnvif.Search.GetRecordingSearchResults.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Search.GetRecordingSearchResults.html#to_struct/1","title":"ExOnvif.Search.GetRecordingSearchResults.to_struct/1","type":"function"},{"doc":"A module describing recording information.","ref":"ExOnvif.Search.RecordingInformation.html","title":"ExOnvif.Search.RecordingInformation","type":"module"},{"doc":"","ref":"ExOnvif.Search.RecordingInformation.html#changeset/2","title":"ExOnvif.Search.RecordingInformation.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Search.RecordingInformation.html#parse/1","title":"ExOnvif.Search.RecordingInformation.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Search.RecordingInformation.html#t:t/0","title":"ExOnvif.Search.RecordingInformation.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Search.RecordingInformation.html#to_json/1","title":"ExOnvif.Search.RecordingInformation.to_json/1","type":"function"},{"doc":"","ref":"ExOnvif.Search.RecordingInformation.html#to_struct/1","title":"ExOnvif.Search.RecordingInformation.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Search.RecordingInformation.RecordingSourceInformation.html","title":"ExOnvif.Search.RecordingInformation.RecordingSourceInformation","type":"module"},{"doc":"","ref":"ExOnvif.Search.RecordingInformation.TrackInformation.html","title":"ExOnvif.Search.RecordingInformation.TrackInformation","type":"module"},{"doc":"Schema describing recording summary.","ref":"ExOnvif.Search.RecordingSummary.html","title":"ExOnvif.Search.RecordingSummary","type":"module"},{"doc":"","ref":"ExOnvif.Search.RecordingSummary.html#changeset/2","title":"ExOnvif.Search.RecordingSummary.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Search.RecordingSummary.html#parse/1","title":"ExOnvif.Search.RecordingSummary.parse/1","type":"function"},{"doc":"","ref":"ExOnvif.Search.RecordingSummary.html#t:t/0","title":"ExOnvif.Search.RecordingSummary.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Search.RecordingSummary.html#to_struct/1","title":"ExOnvif.Search.RecordingSummary.to_struct/1","type":"function"},{"doc":"A module representing a schema for search scope.","ref":"ExOnvif.Search.SearchScope.html","title":"ExOnvif.Search.SearchScope","type":"module"},{"doc":"","ref":"ExOnvif.Search.SearchScope.html#changeset/2","title":"ExOnvif.Search.SearchScope.changeset/2","type":"function"},{"doc":"","ref":"ExOnvif.Search.SearchScope.html#encode/1","title":"ExOnvif.Search.SearchScope.encode/1","type":"function"},{"doc":"","ref":"ExOnvif.Search.SearchScope.html#t:t/0","title":"ExOnvif.Search.SearchScope.t/0","type":"type"},{"doc":"","ref":"ExOnvif.Search.SearchScope.html#to_json/1","title":"ExOnvif.Search.SearchScope.to_json/1","type":"function"},{"doc":"","ref":"ExOnvif.Search.SearchScope.html#to_struct/1","title":"ExOnvif.Search.SearchScope.to_struct/1","type":"function"},{"doc":"","ref":"ExOnvif.Search.SearchScope.SourceReference.html","title":"ExOnvif.Search.SearchScope.SourceReference","type":"module"},{"doc":"# ExOnvif\n\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_onvif.svg)](https://hex.pm/packages/ex_onvif)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/ex_onvif)\n\n*Originally forked from https://github.com/hammeraj/onvif*\n\nElixir interface for Onvif functions.","ref":"readme.html","title":"ExOnvif","type":"extras"},{"doc":"The package can be installed by adding `onvif` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_onvif, \"~> 0,7.1\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - ExOnvif","type":"extras"},{"doc":"This library provides an interface for an Elixir application to make requests to Onvif compliant devices.\n\nA request requires a `Device` struct which contains data necessary to successfully make the request, including\nan address, username, password, a best guess at which authentication method will work, and paths for several\nonvif services, include Media and Device services. \n\nAn Onvif compliant device should implement functions outlined in Onvif documentation, depending on which profiles with which the \ndevice claims to be compliant. That said, a disclaimer that nothing is guaranteed and devices may not respond to requests for \nservices that should be implemented.\n\nTo start, make a probe request:\n```elixir\n> ExOnvif.Discovery.probe()\n[\n  %ExOnvif.Discovery.Probe{\n    address: ...\n  }\n]\n```\n\nThis will return a list of devices on the network that respond to Web Services Dynamic Discovery. The request\n_should_ filter any non-video device but it is possibly that printers, etc. will show up and will need to be\nfiltered by application logic. If you already have information about the device, you can use:\n\n```elixir\n> ExOnvif.Discovery.probe_by(ip_address: \"127.0.0.1\")\n%ExOnvif.Discovery.Probe{\n  address: [...],\n  device_ip: \"127.0.0.1\",\n  ...\n}\n```\nMore details in the `ExOnvif.Discovery.probe_by/1` docs.\n\nOnce you have a valid `Probe` struct, you can initialize a device.\n\n```elixir\n> ExOnvif.Device.init(probe, username, password)\n%ExOnvif.Device{\n  ...\n}\n```","ref":"readme.html#how-to-use","title":"How to use - ExOnvif","type":"extras"}],"producer":{"name":"ex_doc","version":"0.36.1"},"proglang":"elixir"}